@@ -1603,6 +1603,12 @@ on_session_save (AnjutaShell *shell, AnjutaSessionPhase phase,
 								   "Program arguments", plugin->program_args);
 	anjuta_session_set_int (session, "Execution", "Run in terminal",
 							plugin->run_in_terminal + 1);
+	if (plugin->last_exec_uri)
+	{
+		anjuta_session_set_string (session, "Execution",
+								   "Last selected uri", plugin->last_exec_uri);
+	}		
+	
 	if (plugin->configure_args)
 		anjuta_session_set_string (session, "Build",
 								   "Configure parameters",
@@ -1613,7 +1619,7 @@ static void
 on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
 				 AnjutaSession *session, BasicAutotoolsPlugin *plugin)
 {
-	gchar *program_args, *configure_args;
+	gchar *program_args, *configure_args, *last_uri;
 	gint run_in_terminal;
 				
 	if (phase != ANJUTA_SESSION_PHASE_NORMAL)
@@ -1635,6 +1641,14 @@ on_session_load (AnjutaShell *shell, AnjutaSessionPhase phase,
 		plugin->configure_args = configure_args;
 	}
 	
+	last_uri = anjuta_session_get_string (session, "Execution",
+								   "Last selected uri");
+	
+	if (last_uri)
+	{
+		plugin->last_exec_uri = last_uri;
+	}
+	
 	/* The flag is store as 1 == FALSE, 2 == TRUE */
 	run_in_terminal =
 		anjuta_session_get_int (session, "Execution", "Run in terminal");
@@ -2077,6 +2091,7 @@ basic_autotools_plugin_instance_init (GObject *obj)
 	ba_plugin->configure_args = NULL;
 	ba_plugin->program_args = NULL;
 	ba_plugin->run_in_terminal = TRUE;
+	ba_plugin->last_exec_uri = NULL;
 	ba_plugin->editors_created = g_hash_table_new (g_direct_hash,
 												   g_direct_equal);
 }
